#
# spec file for package leveldb
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           leveldb
Version:        1.18
Release:        lp152.3.9
Summary:        A key/value-store
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://github.com/google/leveldb
Source0:        https://github.com/google/leveldb/archive/v%{version}.tar.gz
Patch0:         0001-debian-ports.patch
BuildRequires:  gcc-c++
BuildRequires:  snappy-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
leveldb implements a system for maintaining a persistent key/value store.

%define lib_name libleveldb1

%package -n %{lib_name}
Summary:        Shared library from leveldb
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{lib_name}
leveldb implements a system for maintaining a persistent key/value store.

This package holds the shared library of leveldb.

%package devel
Summary:        Development files for leveldb
Group:          Development/Libraries/C and C++
Requires:       %{lib_name} = %{version}

%description devel
leveldb implements a system for maintaining a persistent key/value store.

This package holds the development files for leveldb.

%package devel-static
Summary:        Development files for statically link leveldb
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description devel-static
leveldb implements a system for maintaining a persistent key/value store.

This package holds the development files for statically linking leveldb.

%prep
%setup -q
%patch0 -p1

%build
make %{?_smp_mflags} OPT="%{optflags}"

%check
make %{?_smp_mflags} check

%install
install -d -m 0755 %{buildroot}%{_includedir} %{buildroot}%{_libdir}

cp -a \
    libleveldb.a   \
    libleveldb.so* \
  %{buildroot}%{_libdir}

cp -a include/leveldb   %{buildroot}%{_includedir}
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%defattr(-,root,root,-)
%{_libdir}/libleveldb.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libleveldb.so
%{_includedir}/leveldb/
%doc AUTHORS LICENSE NEWS README TODO doc/*

%files devel-static
%defattr(-,root,root,-)
%{_libdir}/libleveldb.a

%changelog
* Wed Mar 14 2018 ncutler@suse.com
- revert to 1.18 because 1.20 causes ceph-osd to crash
  (bsc#1054194, bsc#1083921)
- FATE#319443 (aarch64 enablement) changes were backported by
  https://build.opensuse.org/request/show/294636 and are part
  of this release. Factory version builds on aarch64.
  (bsc#1041611)
* Sun Apr  5 2015 mpluskal@suse.com
- Update project url
- Use url for source
- Enable tests
* Mon Oct 20 2014 dmueller@suse.com
- update to 1.18:
  + Replace the basic fprintf call with a call to fwrite
  + Fix ALL the header guards.
  + A new CONTRIBUTING file.
  + leveldb: Remove unused function 'ConsumeChar'.
  + leveldbutil: Remove unused member variables from WriteBatchItemPrinter.
  + Verify checksums of index/meta/filter blocks when paranoid_checks set.
  + Invoke all tools for iOS with xcrun. (This was causing problems with the new XCode 5.1.1 image on pulse.)
  + include only once, and fix the following linter warning: "Found C system header after C++ system header"
  + When encountering a corrupted table file, return Status::Corruption instead of Status::InvalidArgument.
  + Support cygwin as build platform, patch is from https://code.google.com/p/leveldb/issues/detail?id=188
  + Fix typo, merge patch from https://code.google.com/p/leveldb/issues/detail?id=159
  + Fix typos and comments, and address the following two issues:
  + Add missing db synchronize after "fillseq" in the benchmark.
  + Removed unused variable in SeekRandom: value (issue #201)
* Mon Apr  7 2014 ddiss@suse.com
- updated to 1.16.0
  + Make Log::Reader not report a corruption when the last record in a
    log file is truncated.
  + Fix issue 224: variable created but not utilized.
  + Remove comment that referenced a removed feature.
* Wed Feb  5 2014 ddiss@suse.com
- updated to 1.15.0
  + switched from mmap based writing to simpler stdio based writing. Has
    a minor impact (0.5 microseconds) on microbenchmarks for asynchronous
    writes. Synchronous writes speed up from 30ms to 10ms on linux/ext4.
    Should be much more reliable on diverse platforms.
  + compaction errors now immediately put the database into a read-only
    mode (until it is re-opened). As a downside, a disk going out of
    space and then space being created will require a re-open to recover
    from, whereas previously that would happen automatically. On the
    plus side, many corruption possibilities go away.
  + force the DB to enter an error-state so that all future writes fail
    when a synchronous log write succeeds but the sync fails.
  + repair now regenerates sstables that exhibit problems
  + fix issue 218 - Use native memory barriers on OSX
  + fix issue 212 - QNX build is broken
  + fix build on iOS with xcode 5
  + make tests compile and pass on windows
- refreshed 0001-debian-ports.patch
  + moved OS_MACOSX hunk
* Wed Dec 18 2013 ro@suse.de
- add support for other archs (taken from debian, 0001-debian-ports.patch)
* Sun Nov  3 2013 ddiss@suse.com
- Changed shared libs group to System/Libraries.
* Sun Oct 13 2013 i@marguerite.su
- ran spec-cleaner. too casual the specfile was.
- make check/make clean is no more for OBS.
- add Provides/Obsoletes to libleveldb1.
  * no one know that name, provide leveldb itself
  * required by python-leveldb and python3-leveldb
* Tue Oct  8 2013 ddiss@suse.com
- Updated to 1.14.0
* Tue Jul 16 2013 ddiss@suse.com
- Updated to 1.12.0
  + removed shared_library.patch, now upstream.
* Wed Feb  8 2012 mrueckert@suse.de
- added shared library patch
- update to shared/static library packaging policy
* Wed Feb  8 2012 mrueckert@suse.de
- initial package
